"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const ts_log_debug_1 = require("ts-log-debug");
const _core_1 = require("../core");
const consoleLog = console.log.bind(console);
let LennethConsoleAppender = class LennethConsoleAppender extends ts_log_debug_1.BaseAppender {
    write(loggingEvent) {
        consoleLog(this.layout(loggingEvent, this.config.timezoneOffset));
    }
};
LennethConsoleAppender = tslib_1.__decorate([
    ts_log_debug_1.Appender({ name: "LennethConsoleAppender" })
], LennethConsoleAppender);
let JsonLayout = class JsonLayout extends ts_log_debug_1.BaseLayout {
    transform(loggingEvent) {
        const log = {
            startTime: loggingEvent.startTime,
            categoryName: loggingEvent.categoryName,
            level: loggingEvent.level.toString(),
            data: loggingEvent.data,
            context: loggingEvent.context
        };
        return JSON.stringify(log);
    }
};
JsonLayout = tslib_1.__decorate([
    ts_log_debug_1.Layout({ name: "customJson" })
], JsonLayout);
class LoggerService {
    constructor(loggerName = "lenneth") {
        this._loggerName = loggerName;
    }
    info(msg) {
        this.use().info(msg);
    }
    debug(msg) {
        this.use().debug(msg);
    }
    warn(msg) {
        this.use().warn(msg);
    }
    error(msg) {
        this.use().error(msg);
    }
    drawTable(list, setting) {
        return this.use().drawTable(list, setting);
    }
    use() {
        const logger = new ts_log_debug_1.Logger(this._loggerName);
        const serverSettingMap = _core_1.LennethSetting.serverSettingMap;
        let logFileSetting = serverSettingMap.get("logFileSetting");
        logger.appenders.set("std-log", {
            type: "LennethConsoleAppender",
            level: ["debug", "info"]
        });
        if (logFileSetting && logFileSetting.useFlag) {
            logger.appenders.set("file-log", {
                type: "file",
                filename: logFileSetting.filename || "error.log",
                maxLogSize: logFileSetting.maxLogSize || 10485760,
                backups: logFileSetting.backups || 3,
                compress: true,
                levels: logFileSetting.levels || ["error", "warn"],
                layout: { type: "customJson" }
            });
        }
        return logger;
    }
}
exports.LoggerService = LoggerService;
//# sourceMappingURL=logger.service.js.map