"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_service_1 = require("./base.service");
const _common_1 = require("../common");
const _utils_1 = require("../utils");
class ParamsService extends base_service_1.BaseService {
    static fomartParamsMapKey(target, propertyKey) {
        return `${_utils_1.getClassName(target)}_${propertyKey}`;
    }
    paramsToList(paramsMapKey, ctx, next) {
        if (!ParamsService.paramsMap.has(paramsMapKey))
            return [];
        return ParamsService.paramsMap.get(paramsMapKey).map(item => {
            switch (item.paramsType) {
                case _common_1.ParamsType.PATHPARAMS:
                    return ctx.params[item.paramsKey];
                case _common_1.ParamsType.QUERYPARAMS:
                    return ctx.request.query[item.paramsKey];
                case _common_1.ParamsType.BODYPARAMS:
                    return item.paramsKey
                        ? ctx.request.body[item.paramsKey]
                        : ctx.request.body;
                case _common_1.ParamsType.REQUEST:
                    return ctx.req;
                case _common_1.ParamsType.RESPONSE:
                    return ctx.response;
                case _common_1.ParamsType.NEXT:
                    return next;
                case _common_1.ParamsType.HEADERPARAMS:
                    return item.paramsKey
                        ? ctx.request.headers[item.paramsKey]
                        : ctx.request.headers;
                default:
                    break;
            }
        });
    }
    paramsToErrorList(paramsMapKey, err, ctx) {
        if (!ParamsService.paramsMap.has(paramsMapKey))
            return [];
        return ParamsService.paramsMap.get(paramsMapKey).map(item => {
            switch (item.paramsType) {
                case _common_1.ParamsType.ERROR:
                    return {
                        message: err.message,
                        status: err["status"] || _common_1.HttpStatus.INTERNAL_SERVER_ERROR,
                        data: err["errorData"]
                    };
                default:
                    break;
            }
        });
    }
}
ParamsService.paramsMap = new Map();
exports.ParamsService = ParamsService;
//# sourceMappingURL=params.service.js.map