"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const Router = require("koa-router");
const _decorators_1 = require("../decorators");
const _constants_1 = require("../constants");
const _common_1 = require("../common");
const params_service_1 = require("./params.service");
const logger_service_1 = require("./logger.service");
const _utils_1 = require("../utils");
class RouterService {
    constructor() { }
    loadRouter(app) {
        let controllerList = [];
        let descriptionsMap = RouterService.DescriptionMap;
        for (let [config, controllers] of RouterService.DecoratedRouters) {
            if (!_utils_1.isArray(controllers)) {
                controllers = _utils_1.toArray(controllers);
            }
            controllers = controllers.map(item => {
                let controllerName = item.name != "use"
                    ? item.name
                    : `${config.name}_${item[_constants_1.LENNETH_MIDDLEWARE_NAME]}`;
                let paramsMapKey = params_service_1.ParamsService.fomartParamsMapKey(config.target, controllerName);
                return _utils_1.toAsyncMiddleware(config.target, item, paramsMapKey, this.paramsService.paramsToList);
            });
            let routerPath = path
                .join(_common_1.Metadata.getOwn(`${_constants_1.LENNETH_CONTROLLER_PATH}_${_utils_1.getClassName(config.target)}`, config.target), config.path)
                .split(path.sep)
                .join("/");
            let multerKey = `${_utils_1.getClassName(config.target)}_${config.name}_Multer`;
            if (config.target[multerKey]) {
                controllers.unshift(config.target[multerKey]);
            }
            this.router[config.method.toLocaleLowerCase()](routerPath, ...controllers);
            controllerList.push({
                method: config.method,
                url: routerPath,
                name: `${_utils_1.getClassName(config.target)}.${config.name}`,
                description: descriptionsMap.get(_utils_1.apiDescriptionMapKey(config.target, config.name)) || ""
            });
        }
        app.use(this.router.routes());
        app.use(this.router.allowedMethods());
        let logstr = this.loggerService.drawTable(controllerList, {
            padding: 1,
            header: {
                method: "Method",
                url: "Endpoint",
                name: "Class method",
                description: "Description"
            }
        });
        this.loggerService.info("\n" + logstr.trim());
        RouterService.DescriptionMap.clear();
        RouterService.DecoratedRouters.clear();
    }
    joinControllerPath(imports) {
        Object.keys(imports).forEach(key => {
            if (_utils_1.isArray(imports[key])) {
                imports[key].forEach(item => {
                    let metadataName = `${_constants_1.LENNETH_CONTROLLER_PATH}_${_utils_1.getClassName(item)}`;
                    let controllerPath = path
                        .join(this._startWithSep(key), _common_1.Metadata.getOwn(metadataName, item))
                        .split(path.sep)
                        .join("/");
                    _common_1.Metadata.set(metadataName, controllerPath, item);
                });
            }
            else {
                let metadataName = `${_constants_1.LENNETH_CONTROLLER_PATH}_${_utils_1.getClassName(imports[key])}`;
                let importsPath = _common_1.Metadata.getOwn(metadataName, imports[key]);
                let controllerPath = path
                    .join(this._startWithSep(key), importsPath)
                    .split(path.sep)
                    .join("/");
                _common_1.Metadata.set(metadataName, controllerPath, imports[key]);
            }
        });
    }
    _startWithSep(key) {
        if (!key.startsWith("/")) {
            key = `/${key}`;
        }
        return key;
    }
}
RouterService.DecoratedRouters = new Map();
RouterService.DescriptionMap = new Map();
tslib_1.__decorate([
    _decorators_1.Autowired(),
    tslib_1.__metadata("design:type", Router)
], RouterService.prototype, "router", void 0);
tslib_1.__decorate([
    _decorators_1.Autowired(),
    tslib_1.__metadata("design:type", params_service_1.ParamsService)
], RouterService.prototype, "paramsService", void 0);
tslib_1.__decorate([
    _decorators_1.Autowired(),
    tslib_1.__metadata("design:type", logger_service_1.LoggerService)
], RouterService.prototype, "loggerService", void 0);
exports.RouterService = RouterService;
//# sourceMappingURL=router.service.js.map